@@ -1,28 +1,15 @@
 /*
-  Copyright (c) 2019-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
 #include "changedebugmodejob.h"
-#include "kdebugsettingsloadingcategories.h"
 #include "kdebugsettings_debug.h"
-#include "saverulesjob.h"
+#include "kdebugsettingsloadingcategories.h"
 #include "kdebugsettingsutil.h"
+#include "saverulesjob.h"
 
 ChangeDebugModeJob::ChangeDebugModeJob()
 {
@@ -142,7 +129,8 @@ void ChangeDebugModeJob::setLoggingCategoriesName(const QStringList &loggingCate
 
 bool ChangeDebugModeJob::debugModeIsValid(const QString &value) const
 {
-    if (value == QLatin1String("Full") || value == QLatin1String("Info") || value == QLatin1String("Warning") || value == QLatin1String("Critical") || value == QLatin1String("Off")) {
+    if (value == QLatin1String("Full") || value == QLatin1String("Info") || value == QLatin1String("Warning") || value == QLatin1String("Critical")
+        || value == QLatin1String("Off")) {
         return true;
     }
     return false;
